import { BrowserModule } from '@angular/platform-browser';
import { SharedModule } from 'src/app/shared/shared.module';
import { CoreModule } from 'src/app/shared/core.module';
import { APP_INITIALIZER, NgModule, Injector, Injectable } from '@angular/core';
import { StoreDevtoolsModule } from '@ngrx/store-devtools';
import { AppComponent } from './app.component';
import { DataService } from 'src/app/shared/services/data.config.service';
import { StoreModule } from '@ngrx/store';
import { acquisitionReducer } from 'src/app/shared/state/acquisition/acquisition.reducer';
import { EffectsModule } from '@ngrx/effects';
import { environment } from 'src/environments/environment';
import { LoggerModule, NgxLoggerLevel } from 'ngx-logger';
import { AppInjector } from './app-injector.service';
import { AppSettings } from 'src/app/shared/app.settings';
import { Socket } from 'ngx-socket-io';
import { SocketIoModule } from 'ngx-socket-io';
import { RouterModule } from '@angular/router';
import { rootRouterConfig } from './app-routing';
import { IhmFrameworkModule } from 'src/app/ihm-framework/ihm-framework.module';


export function appInit(dataConfigSvc: DataService) {
  return () => dataConfigSvc.load();
}
//const socketIoConfig: SocketIoConfig = { url: 'http://192.168.1.15:4001', options: {} };

@Injectable()
export class SignalMgrSocket extends Socket {
  constructor() {
    super({ url: AppSettings.SIGNAL_MGR_ENDPOITNT, options: {} });
  }
}
@Injectable()
export class EventMgrSocket extends Socket {
  constructor() {
    super({ url: AppSettings.EVENT_MGR_ENDPOITNT, options: {} });
  }
}
@Injectable()
export class AlarmMgrSocket extends Socket {
  constructor() {
    super({ url: AppSettings.ALARM_MGR_ENDPOITNT, options: {} });
  }
}

@NgModule({
  declarations: [
    AppComponent
  ],
  imports: [
    BrowserModule,
    SharedModule,
    CoreModule,
    RouterModule.forRoot(rootRouterConfig, { enableTracing: false }),
    StoreDevtoolsModule.instrument({
      maxAge: 25,
      logOnly: environment.production
    }),
    StoreModule.forRoot(acquisitionReducer),
    EffectsModule.forRoot([]),
    !environment.production ? StoreDevtoolsModule.instrument() : [],
    LoggerModule.forRoot({ serverLoggingUrl: '/api/logs', level: NgxLoggerLevel.WARN, serverLogLevel: NgxLoggerLevel.ERROR }),
    SocketIoModule
  ],
  providers: [DataService,
    {
      provide: APP_INITIALIZER,
      useFactory: appInit,
      multi: true,
      deps: [DataService]
    },
    SignalMgrSocket, EventMgrSocket, AlarmMgrSocket
  ],
  bootstrap: [AppComponent]
})
export class AppModule {
  constructor(injector: Injector) {
    AppInjector.injector = injector;
  }
}
