import { Component, OnInit, ViewChild, OnDestroy } from '@angular/core';
import { Observable, Subscription } from 'rxjs';
import { Alarm } from 'src/app/shared/models/alarm.model';
import { NGXLogger } from 'ngx-logger';
import { AlarmsStoreFacade } from 'src/app/shared/state/alarm/alarm.store-facade';
import { MatPaginator } from '@angular/material/paginator';
import { MatTableDataSource } from '@angular/material/table';
import { MatSort } from '@angular/material/sort';
import { EventsStoreFacade } from 'src/app/shared/state/event/event.store-facade';

@Component({
  selector: 'app-alarms-table',
  templateUrl: './alarms-table.component.html',
  styleUrls: ['./alarms-table.component.scss']
})
export class AlarmsTableComponent implements OnInit, OnDestroy {

  public alarms$: Observable<Alarm[]> = this.alarmsStoreFacade.alarms$;


  public alarmsDisplayedColumns: string[] = ['id', 'source', 'severity', 'description', 'appeared', 'acknowledged', 'actions'];
  dataSource = new MatTableDataSource<Alarm>([]);
  private _sub2alarms: Subscription;

  @ViewChild(MatPaginator) paginator: MatPaginator;
  @ViewChild(MatSort) sort: MatSort;

  constructor(private alarmsStoreFacade: AlarmsStoreFacade,
    private eventsStoreFacade: EventsStoreFacade,
    private logger: NGXLogger) {
  }

  ngOnInit(): void {
    this._sub2alarms = this.alarms$.subscribe((alarms) => {
      this.dataSource.data = alarms.filter((alarm) => alarm.disappeared != 0);
      this.dataSource.paginator = this.paginator;
      this.dataSource.sort = this.sort;
    });

  }

  acknowledge(element) {
    this.logger.trace("acknowledge ");
    if (element) {
      // first of all, we update the offer
      let alarm: Alarm = { ...element };
      alarm.acknowledged = Date.now();
      this.alarmsStoreFacade.updateAlarm(alarm);

      let event = {
        id: -1,
        type: 'ALARM',
        timestamp: Date.now(),
        source: 'AlarmTable',
        description: "Alarm " + alarm.description + " has been acknowledged"
      }
      this.eventsStoreFacade.addEvent(event);
    }

  }
  ngOnDestroy() {
    this._sub2alarms.unsubscribe();
  }
}
