import { Component, OnDestroy, OnInit } from '@angular/core';
import { Observable } from 'rxjs';
import { EventsStoreFacade } from 'src/app/shared/state/event/event.store-facade';
import { AcquisitionsService } from 'src/app/shared/services/acquisitions.service';
import { AlarmsService } from 'src/app/shared/services/alarms.service';
import { EventsService } from 'src/app/shared/services/events.service';
import { AppSettings } from 'src/app/shared/app.settings';

@Component({
  selector: 'app-health-display',
  templateUrl: './health-display.component.html',
  styleUrls: ['./health-display.component.scss']
})
export class HealthDisplayComponent implements OnInit, OnDestroy {

  public isAcqAlive: boolean = false;
  public isAlarmAlive: boolean = false;
  public isEventAlive: boolean = false;
  private _acqTimer: any = null;
  private _alarmTimer: any = null;
  private _eventTimer: any = null;
  private _clock: any = null;
  public currentDate: number = Date.now();

  constructor(private acqSvc: AcquisitionsService, private alarmSvc: AlarmsService,
    private eventsvc: EventsService, private eventsStoreFacade: EventsStoreFacade,) { }


  ngOnInit(): void {

    this.acqSvc.watchdog.subscribe(
      (wd) => {

        if (this._acqTimer) {
          clearTimeout(this._acqTimer);
        }
        if (this.isAcqAlive != wd) {
          console.log(wd);
          console.log(this.isAcqAlive);
          this.isAcqAlive = wd;
          let event = {
            id: -1,
            type: 'WATCHDOG',
            timestamp: Date.now(),
            source: 'SymbolComponent',
            description: "Communication with signal manager has been recovered"
          };
          this.eventsStoreFacade.addEvent(event);

        }
        this._acqTimer = setTimeout(() => {
          this.isAcqAlive = false;
          let event = {
            id: -1,
            type: 'WATCHDOG',
            timestamp: Date.now(),
            source: 'SymbolComponent',
            description: "Communication with signal manager has been lost"
          };
          this.eventsStoreFacade.addEvent(event);
        }, AppSettings.WD_TIMEOUT);
      });

    this.alarmSvc.watchdog.subscribe(
      (wd) => {

        if (this._alarmTimer) {
          clearTimeout(this._alarmTimer);
        }
        this.isAlarmAlive = wd;

        this._alarmTimer = setTimeout(() => {
          this.isAlarmAlive = false;
        }, AppSettings.WD_TIMEOUT);
      });

    this.eventsvc.watchdog.subscribe(
      (wd) => {

        if (this._eventTimer) {
          clearTimeout(this._eventTimer);
        }
        this.isEventAlive = wd;
        this._eventTimer = setTimeout(() => {
          this.isEventAlive = false;
        }, AppSettings.WD_TIMEOUT);
      });

    this._clock = setInterval(() => {
      this.currentDate = Date.now();
    }, 1000);
  }
  ngOnDestroy() {
    clearTimeout(this._acqTimer);
    clearTimeout(this._alarmTimer);
    clearTimeout(this._eventTimer);
    clearInterval(this._clock);
  }

}
