import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { ScrollingModule } from '@angular/cdk/scrolling';
import { IhmFrameworkComponent } from './ihm-framework.component';
import { SignalMgrSocket, EventMgrSocket, AlarmMgrSocket } from 'src/app/app.module';
import { SharedModule } from 'src/app/shared/shared.module';
import { AcquisitionsService } from 'src/app/shared/services/acquisitions.service';
import { HealthDisplayComponent } from './health-display/health-display.component';
import { EventDisplayComponent } from './event-display/event-display.component';
import { AlarmsTableComponent } from './alarms-table/alarms-table.component';
import { SynoManagerModule } from './../views/syno-manager/syno-manager.module';
import { IhmFrameworkRoutingModule } from 'src/app/ihm-framework/ihm-framework-routing.module';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';
import * as fromAcq from 'src/app/shared/state/acquisition';
import * as fromEvents from 'src/app/shared/state/event';
import * as fromAlarms from 'src/app/shared/state/alarm';
import { AcquisitionsEffects } from 'src/app/shared/state/acquisition/acquisition.effects';
import { EventsEffects } from 'src/app/shared/state/event/event.effects';
import { AlarmsEffects } from 'src/app/shared/state/alarm/alarm.effects';
import { AcquisitionsStoreFacade } from 'src/app/shared/state/acquisition/acquisition.store-facade';
import { EventsStoreFacade } from 'src/app/shared/state/event/event.store-facade';
import { AlarmsStoreFacade } from 'src/app/shared/state/alarm/alarm.store-facade';


@NgModule({
  declarations: [IhmFrameworkComponent, HealthDisplayComponent, EventDisplayComponent, AlarmsTableComponent],
  imports: [
    CommonModule, ScrollingModule,
    SharedModule, SynoManagerModule, IhmFrameworkRoutingModule,
    StoreModule.forFeature('acqs', fromAcq.reducers),
    StoreModule.forFeature('events', fromEvents.reducers),
    StoreModule.forFeature('alarms', fromAlarms.reducers),
    EffectsModule.forFeature([AcquisitionsEffects, EventsEffects, AlarmsEffects]),
  ],
  providers: [AcquisitionsService,
    SignalMgrSocket, EventMgrSocket, AlarmMgrSocket,
    AcquisitionsStoreFacade, EventsStoreFacade, AlarmsStoreFacade
  ]
})
export class IhmFrameworkModule { }
