import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { Acquisition } from 'src/app/shared/models/acquisition.model';
import { NGXLogger } from 'ngx-logger';
import { SignalMgrSocket } from 'src/app/app.module';
import { AppSettings } from 'src/app/shared/app.settings';

@Injectable({
    providedIn: 'root'
})
export class AcquisitionsService {

    acqList = this.socket.fromEvent<string>('acqs');
    watchdog = this.socket.fromEvent<boolean>('health');

    constructor(private socket: SignalMgrSocket, private logger: NGXLogger) {

    }

    getAllAcquisitions(): Observable<Acquisition[]> {
        this.logger.debug('getAllAcquisitions');
        return new Observable((subscriber) => {

            this.acqList.subscribe(
                (acqs) => {
                    subscriber.next(JSON.parse(acqs));
                });
        });
    }


    getAcquisition(acqId: number): Observable<Acquisition> {
        this.logger.trace('getAcquisition ' + acqId.toString());
        this.socket.emit('getAcq', acqId.toString());
        return new Observable((subscriber) => {
            this.socket.on('acq_' + acqId.toString(), (data) => {
                subscriber.next(data);
            });
        });
    }

}
