import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { Alarm } from 'src/app/shared/models/alarm.model';
import { NGXLogger } from 'ngx-logger';
import { AlarmMgrSocket } from 'src/app/app.module';

@Injectable({
    providedIn: 'root'
})
export class AlarmsService {

    alarmList = this.socket.fromEvent<string>('alarms');
    watchdog = this.socket.fromEvent<boolean>('health');

    constructor(private socket: AlarmMgrSocket, private logger: NGXLogger) {
    }

    getAlarms(): Observable<Alarm[]> {
        this.logger.debug('getAlarms');

        this.socket.emit('getAllAlarms');

        return new Observable((subscriber) => {
            this.alarmList.subscribe((alarms) => {
                this.logger.debug(JSON.parse(alarms));
                subscriber.next(JSON.parse(alarms));
            });
        });
    }
    updateAlarm(alarm: Alarm): Observable<Alarm> {
        this.logger.trace('updateAlarm');
        this.logger.debug('received alarm for update', alarm);
        this.socket.emit('updateAlarm', alarm);
        return new Observable((subscriber) => {
            this.alarmList.subscribe((alarms) => {
                this.logger.debug(JSON.parse(alarms));
                subscriber.next(JSON.parse(alarms));
            });
        });
    }

}
