import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { AppSettings } from '../app.settings';
import { Command } from 'src/app/shared/models/command.model';
import { NGXLogger } from 'ngx-logger';
import { SignalMgrSocket } from 'src/app/app.module';

@Injectable({
    providedIn: 'root'
})
export class CommandsService {

    cmdList = this.socket.fromEvent<string>('cmds');

    constructor(private socket: SignalMgrSocket, private logger: NGXLogger) {
    }

    getCommands(): Observable<Command[]> {
        this.logger.debug('getCommands');

        this.socket.emit('getAllCmds');

        return new Observable((subscriber) => {
            this.cmdList.subscribe((cmds) => {
                this.logger.debug(JSON.parse(cmds));
                subscriber.next(JSON.parse(cmds));
            });
        });
    }
    updateCommand(command: Command): Observable<Command> {
        this.logger.trace('updateCommand');
        this.logger.debug('received command for update', command);
        this.socket.emit('updateCmd', command);
        return new Observable((subscriber) => {
            this.cmdList.subscribe((cmds) => {
                this.logger.debug(JSON.parse(cmds));
                subscriber.next(JSON.parse(cmds));
            });
        });
    }

}
