import { Injectable } from '@angular/core';
import { Observable, Subject } from 'rxjs';
import { Sign } from 'src/app/shared/models/sign.model';
import { Synoptic } from 'src/app/shared/models/synoptic.model';
import * as symbolData from 'src/assets/config/symbolsDatabase.json';
import * as synoData from 'src/assets/config/synoDatabase.json';
import * as synoTree from 'src/assets/config/synoMenu.json';

@Injectable({
    providedIn: 'root'
})
export class DataService {
    public synoMap: Map<string, Synoptic> = new Map();
    public symbolMap: Map<string, Sign> = new Map();
    public acqBySymbol: Map<string, string[]> = new Map();
    public synoTree: any[] = [];

    private loadDataSub = new Subject<any>();
    loadDataObservable$ = this.loadDataSub.asObservable();

    emitLoadDataSuccess() {
        this.loadDataSub.next();
    }

    constructor() {
        this.symbolMap = new Map();
        this.synoMap = new Map();
    }
    load(): Promise<any> {

        return new Promise<void>(resolve => {
            symbolData['default'].forEach(sign => {

                // updates the map of symbols
                this.symbolMap.set(sign['itemName'], sign);

                // updates the map of acq in symbols
                sign['acqs'].forEach(acqName => {
                    let listOfSymbols = [];

                    if (this.acqBySymbol.has(acqName)) {
                        listOfSymbols = this.acqBySymbol.get(acqName);
                        listOfSymbols.push(sign['itemName']);
                    } else {
                        listOfSymbols = [sign['itemName']];
                    }
                    this.acqBySymbol.set(acqName, listOfSymbols);
                });
            });

            synoData['default'].forEach(syno =>
                this.synoMap.set(syno['title'], syno));


            synoTree['default'].map(node => {
                this.synoTree.push(this.addNodeToSynoTree(null, node));

            });

            this.emitLoadDataSuccess();

            resolve();
        });
    }
    addNodeToSynoTree(parent: any, node: any) {

        let treeNode = {};
        if (node.hasOwnProperty('name')) {
            treeNode = {
                name: node.name
            };
        } else if (node.hasOwnProperty('title')) {
            treeNode = {
                name: node.title
            };
        }
        if (!!node.children && node.children.length > 0) {
            treeNode['children'] = [];
            node.children.map(child => this.addNodeToSynoTree(treeNode, child));
        }
        if (parent === null) {
            return treeNode;
        } else {
            parent.children.push(treeNode);
        }
    }
    getSymbolMap(): Map<string, Sign> {
        return this.symbolMap;
    }
    getSymbolData(signal: string): Sign {
        return this.symbolMap.get(signal);
    }
    getSynoTree(): any[] {
        return this.synoTree;
    }
    getSynoData(title: string): Synoptic {
        return this.synoMap.get(title);
    }
}
