import { Injectable } from '@angular/core';
import { Observable, of } from 'rxjs';
import { Event } from 'src/app/shared/models/event.model';
import { NGXLogger } from 'ngx-logger';
import { EventMgrSocket } from 'src/app/app.module';


@Injectable({
    providedIn: 'root'
})
export class EventsService {
    eventList = this.socket.fromEvent<string>('events');
    watchdog = this.socket.fromEvent<boolean>('health');

    constructor(private socket: EventMgrSocket, private logger: NGXLogger) {
    }

    getAllEvents(): Observable<Event[]> {
        this.logger.debug('getAllEvents');

        this.socket.emit('getAllEvents');

        return new Observable((subscriber) => {
            this.eventList.subscribe((events) => {
                subscriber.next(JSON.parse(events));
            });
        });
    }
    addEvent(event: Event): Observable<Event> {
        this.logger.trace('add Event');
        this.logger.debug('received event for addition', event);
        this.socket.emit('addEvent', event);

        // an observable of an event is returned since the 
        // events are continuously updated by the server
        return of(event);
    }

}
