import * as fromreducer from './acquisition.reducer';
import { State } from './acquisition.state';
import { Action, combineReducers, createFeatureSelector, createSelector } from '@ngrx/store';

export interface AcquisitionsState {
    acquisitions: State;
}

/** Provide reducers with AoT-compilation compliance */
export function reducers(state: AcquisitionsState | undefined, action: Action) {
    return combineReducers({
        acquisitions: fromreducer.acquisitionReducer
    })(state, action);
}


/**
 * The createFeatureSelector function selects a piece of state from the root of the state object.
 * This is used for selecting feature states that are loaded eagerly or lazily.
 */
export const getAcquisitionsState = createFeatureSelector<AcquisitionsState>('acqs');

export const getAcquisitionsEntitiesState = createSelector(
    getAcquisitionsState,
    state => state.acquisitions
);

export const {
    selectAll: getAllAcquisitions,
} = fromreducer.acquisitionsAdapter.getSelectors(getAcquisitionsEntitiesState);

export const getAcquisitionById = (id: number) => createSelector(
    getAcquisitionsEntitiesState,
    fromreducer.getAcquisitionById(id)
);

export const getAcquisitionsByName = (name: string) => createSelector(
    getAcquisitionsEntitiesState,
    fromreducer.getAcquisitionsByName(name)
);
