import { Injectable } from '@angular/core';
import {
    catchError,
    map,
    startWith,
    switchMap
} from 'rxjs/operators';
import { of } from 'rxjs';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { AlarmsService } from 'src/app/shared/services/alarms.service';
import {
    loadAllAlarms,
    loadAllAlarmsSuccess,
    updateAlarm,
    updateAlarmSuccess,
    failure
} from 'src/app/shared/state/alarm/alarm.actions';


@Injectable()
export class AlarmsEffects {

    loadAll$ = createEffect(() => this.actions$.pipe(
        ofType(loadAllAlarms),
        startWith(loadAllAlarms()),
        switchMap(() => this.alarmsService.getAlarms().pipe(
            map(alarms => loadAllAlarmsSuccess({ alarms }))
        )),
    ));
    update$ = createEffect(() => this.actions$.pipe(
        ofType(updateAlarm),
        switchMap(({ alarm }) => this.alarmsService.updateAlarm(alarm).pipe(
            map(() => updateAlarmSuccess({ alarm })),
            catchError(err => {
                alert(err.message);
                return of(failure({ err: { concern: 'UPDATE', error: err } }));
            })
        ))
    ));
    constructor(
        private actions$: Actions,
        private alarmsService: AlarmsService
    ) { }


}
