import * as fromreducer from './alarm.reducer';
import { State } from './alarm.state';
import { Action, combineReducers, createFeatureSelector, createSelector } from '@ngrx/store';

export interface AlarmsState {
    alarms: State;
}

/** Provide reducers with AoT-compilation compliance */
export function reducers(state: AlarmsState | undefined, action: Action) {
    return combineReducers({
        alarms: fromreducer.alarmReducer
    })(state, action);
}


/**
 * The createFeatureSelector function selects a piece of state from the root of the state object.
 * This is used for selecting feature states that are loaded eagerly or lazily.
 */
export const getAlarmsState = createFeatureSelector<AlarmsState>('alarms');

export const getAlarmsEntitiesState = createSelector(
    getAlarmsState,
    state => state.alarms
);

export const {
    selectAll: getAllAlarms,
} = fromreducer.alarmsAdapter.getSelectors(getAlarmsEntitiesState);

export const getAlarmById = (id: number) => createSelector(
    getAlarmsEntitiesState,
    fromreducer.getAlarmById(id)
);
