import { Injectable } from '@angular/core';
import {
    catchError,
    map,
    startWith,
    switchMap
} from 'rxjs/operators';
import { of } from 'rxjs';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { CommandsService } from 'src/app/shared/services/commands.service';
import {
    loadAllCommands,
    loadAllCommandsSuccess,
    updateCommand,
    updateCommandSuccess,
    failure
} from 'src/app/shared/state/command/command.actions';


@Injectable()
export class CommandsEffects {

    loadAll$ = createEffect(() => this.actions$.pipe(
        ofType(loadAllCommands),
        startWith(loadAllCommands()),
        switchMap(() => this.commandsService.getCommands().pipe(
            map(commands => loadAllCommandsSuccess({ commands }))
        )),
    ));
    update$ = createEffect(() => this.actions$.pipe(
        ofType(updateCommand),
        switchMap(({ command }) => this.commandsService.updateCommand(command).pipe(
            map(() => updateCommandSuccess({ command })),
            catchError(err => {
                alert(err.message);
                return of(failure({ err: { concern: 'UPDATE', error: err } }));
            })
        ))
    ));
    constructor(
        private actions$: Actions,
        private commandsService: CommandsService
    ) { }
}

