import { loadAllCommandsSuccess, updateCommandSuccess } from 'src/app/shared/state/command/command.actions';
import { State } from 'src/app/shared/state/command/command.state';
import { EntityAdapter, createEntityAdapter } from '@ngrx/entity';
import { Command } from 'src/app/shared/models/command.model';
import { createReducer, on } from '@ngrx/store';


export const commandsAdapter: EntityAdapter<Command> = createEntityAdapter<Command>({
    selectId: (command: Command) => command.id,
    sortComparer: false
});


export const commandsInitialState: State = {
    ids: [],
    entities: { 1: {} as Command }
};
export const commandReducer = createReducer<State>(
    commandsInitialState,
    on(loadAllCommandsSuccess, (state, { commands }) =>
        commandsAdapter.setAll(commands, state)),

    on(updateCommandSuccess, (state, { command }) => {
        return commandsAdapter.updateOne({ id: command.id, changes: command }, state);
    }),
);
export const getCommandById = (id: number) => (state: State) => state.entities[id];

export const getCommandsByName = (cmdName: string) => (state: State) => {
    return Object.values(state.entities).find((cmd) => cmd.signal === cmdName);
};

