import * as fromreducer from './command.reducer';
import { State } from './command.state';
import { Action, combineReducers, createFeatureSelector, createSelector } from '@ngrx/store';

export interface CommandsState {
    commands: State;
}

/** Provide reducers with AoT-compilation compliance */
export function reducers(state: CommandsState | undefined, action: Action) {
    return combineReducers({
        commands: fromreducer.commandReducer
    })(state, action);
}


/**
 * The createFeatureSelector function selects a piece of state from the root of the state object.
 * This is used for selecting feature states that are loaded eagerly or lazily.
 */
export const getCommandsState = createFeatureSelector<CommandsState>('cmds');

export const getCommandsEntitiesState = createSelector(
    getCommandsState,
    state => state.commands
);

export const {
    selectAll: getAllCommands,
} = fromreducer.commandsAdapter.getSelectors(getCommandsEntitiesState);

export const getCommandById = (id: number) => createSelector(
    getCommandsEntitiesState,
    fromreducer.getCommandById(id)
);

export const getCommandsByName = (name: string) => createSelector(
    getCommandsEntitiesState,
    fromreducer.getCommandsByName(name)
);
