import { Injectable } from '@angular/core';
import {
    catchError,
    map,
    startWith,
    switchMap
} from 'rxjs/operators';
import { of } from 'rxjs';
import { Actions, createEffect, ofType } from '@ngrx/effects';
import { EventsService } from 'src/app/shared/services/events.service';
import {
    loadAllEvents,
    loadAllEventsSuccess,
    addEvent,
    addEventSuccess,
    failure
} from 'src/app/shared/state/event/event.actions';


@Injectable()
export class EventsEffects {

    loadAll$ = createEffect(() => this.actions$.pipe(
        ofType(loadAllEvents),
        startWith(loadAllEvents()),
        switchMap(() => this.eventsService.getAllEvents().pipe(
            map(events => loadAllEventsSuccess({ events }))
        )),
    ));
    add$ = createEffect(() => this.actions$.pipe(
        ofType(addEvent),
        switchMap(({ event }) => this.eventsService.addEvent(event).pipe(
            map(() => addEventSuccess({ event })),
            catchError(err => {
                alert(err.message);
                return of(failure({ err: { concern: 'ADD', error: err } }));
            })
        ))
    ));
    constructor(
        private actions$: Actions,
        private eventsService: EventsService
    ) { }


}
