import * as fromreducer from './event.reducer';
import { State } from './event.state';
import { Action, combineReducers, createFeatureSelector, createSelector } from '@ngrx/store';

export interface EventsState {
    events: State;
}

/** Provide reducers with AoT-compilation compliance */
export function reducers(state: EventsState | undefined, action: Action) {
    return combineReducers({
        events: fromreducer.eventReducer
    })(state, action);
}


/**
 * The createFeatureSelector function selects a piece of state from the root of the state object.
 * This is used for selecting feature states that are loaded eagerly or lazily.
 */
export const getEventsState = createFeatureSelector<EventsState>('events');

export const getEventsEntitiesState = createSelector(
    getEventsState,
    state => state.events
);

export const {
    selectAll: getAllEvents,
} = fromreducer.eventsAdapter.getSelectors(getEventsEntitiesState);

export const getEventById = (id: number) => createSelector(
    getEventsEntitiesState,
    fromreducer.getEventById(id)
);
