import {
  Component, OnInit, OnDestroy, ViewChildren, QueryList,
  ComponentFactoryResolver, ComponentFactory, ComponentRef, AfterViewInit,
  TemplateRef, ChangeDetectorRef, Input
} from '@angular/core';

import { DataService } from 'src/app/shared/services/data.config.service';
import { LightIndicatorComponent } from 'src/app/symbols/light-indicator/light-indicator.component';
import { SwitchComponent } from 'src/app/symbols/switch/switch.component';
import { NumberFieldComponent } from 'src/app/symbols/number-field/number-field.component';
import { NumberControlComponent } from 'src/app/symbols/number-control/number-control.component';
import { NGXLogger } from 'ngx-logger';
import { SymbolContainer } from './symbol.container.directive';

const typeMap = {
  'lightIndicator': LightIndicatorComponent,
  'switch': SwitchComponent,
  'numberField': NumberFieldComponent,
  'numberControl': NumberControlComponent
};

@Component({ template: '' })

export class AbstractSynopticComponent implements OnInit, OnDestroy,
  AfterViewInit {

  @Input() currentTemplate: TemplateRef<HTMLElement>;
  @ViewChildren(SymbolContainer) symbolContainers!: QueryList<SymbolContainer>;
  symbolRefs: ComponentRef<any>[] = [];

  public factoryCache: Map<string, ComponentFactory<any>> = new Map();

  constructor(private resolver: ComponentFactoryResolver, private dataSvc: DataService,
    private logger: NGXLogger, private cdRef: ChangeDetectorRef) {

  }

  ngOnInit() {
    console.log('ngOnInit');
  }

  ngAfterViewInit() {

    this.symbolContainers.forEach(container => {
      let factory: ComponentFactory<any>;
      container.view.clear();

      const type = container.el.nativeElement.getAttribute('symbolType');
      this.logger.debug("symbol type = " + type);

      // if this symbol has previously been created, we reuse the factory
      // for performance reasons

      if (this.factoryCache.has(type)) {
        factory = this.factoryCache.get(type);
      } else {
        const compType = typeMap[type];
        factory = this.resolver.resolveComponentFactory(compType);
      }

      const symbolRef = container.view.createComponent(factory);
      const symbolStaticData = this.dataSvc.getSymbolData(container.el.nativeElement.getAttribute('itemName'));
      this.logger.debug(symbolStaticData);
      // attribute itemName includes the name of the item to be represented by this symbol
      symbolRef.instance.updateStaticData(symbolStaticData);

      this.symbolRefs.push(symbolRef);
      this.cdRef.detectChanges();

    });
  }
  ngOnDestroy() {
    this.symbolRefs.map(ref => {
      ref.destroy();
    });
    this.symbolRefs = [];
    this.factoryCache = new Map();
  }
}
