import {
  Component, OnInit, OnDestroy, ViewChildren, ViewContainerRef, QueryList,
  ComponentFactoryResolver, ComponentFactory, ComponentRef, AfterViewInit,
  TemplateRef, ViewChild, ChangeDetectorRef, AfterContentInit, ContentChildren,
  AfterContentChecked, AfterViewChecked, Input
} from '@angular/core';

import { DataService } from 'src/app/shared/services/data.config.service';
import { LightIndicatorComponent } from 'src/app/symbols/light-indicator/light-indicator.component';
import { SwitchComponent } from 'src/app/symbols/switch/switch.component';
import { NumberFieldComponent } from 'src/app/symbols/number-field/number-field.component';
import { NumberControlComponent } from 'src/app/symbols/number-control/number-control.component';

import { NGXLogger } from 'ngx-logger';
import { SymbolContainer } from './symbol.container.directive';

@Component({
  selector: 'app-synoptic',
  templateUrl: 'synoptic.component.html',
  styleUrls: ['./synoptic.component.scss']
})
export class SynopticComponent implements OnInit, OnDestroy, AfterContentInit,
  AfterViewInit, AfterContentChecked, AfterViewChecked {

  @Input() currentTemplate: TemplateRef<HTMLElement>;

  private _lightIndicators: QueryList<SymbolContainer>;
  @ViewChildren(SymbolContainer, { emitDistinctChangesOnly: false }) set lightIndicators(lightIndicators: QueryList<SymbolContainer>) {
    this._lightIndicators = lightIndicators;
    console.log('Incoming QueryList length', lightIndicators.toArray().length);
  }

  get lightIndicators(): QueryList<SymbolContainer> {
    return this._lightIndicators;
  }
  //@ViewChildren('lightIndicatorContainer', { read: ViewContainerRef }) lightIndicators!: QueryList<ViewContainerRef>;
  //@ViewChildren(SymbolContainer) lightIndicators!: QueryList<SymbolContainer>;
  @ViewChildren('switchContainer', { read: ViewContainerRef }) switches!: QueryList<ViewContainerRef>;
  @ViewChildren('numberContainer', { read: ViewContainerRef }) numberFields!: QueryList<ViewContainerRef>;
  @ViewChildren('numberControlContainer', { read: ViewContainerRef }) numberControls!: QueryList<ViewContainerRef>;


  symbolRefs: ComponentRef<any>[] = [];



  constructor(private resolver: ComponentFactoryResolver, private dataSvc: DataService,
    private logger: NGXLogger, private cdRef: ChangeDetectorRef) {

  }

  ngOnInit() {
    console.log('ngOnInit');
  }

  ngAfterContentChecked() {
    console.log('ngAfterContentChecked');
    this.logger.debug(this.lightIndicators);

  }
  ngAfterViewChecked() {
    console.log('ngAfterViewChecked');
    this.logger.debug(this.lightIndicators);
  }

  /*   getSynoTemplate(synoRef: string): TemplateRef<any> {
      if (this.synoTemplateRefs !== undefined && this.synoTemplateRefs.toArray().length > 0) {
        this.currentTemplate = this.synoTemplateRefs.toArray().find(temp => temp.name === synoRef).template;
        console.log('syno1 is found');
      } else {
        return null;
      }
  
    } */
  ngAfterContentInit() {



    console.log('ngAfterContentInit');


  }
  ngAfterViewInit() {


    // this.vc.insert(view);
    this.createLightIndicators();
    this.lightIndicators.changes.subscribe(_ => {
      console.log("lightindicators changed");
      this.createLightIndicators();
    });

    // Dynamically Create the symbol components

    this.createSwitches();
    this.createNumberFields();
    this.createNumberControls();
    this.cdRef.detectChanges();

  }

  ngOnDestroy() {
    this.symbolRefs.map(ref => {
      ref.destroy();
    });
    this.symbolRefs = [];
  }

  refreshComponents() {

    console.log("refreshComponents");
    /*     this.createLightIndicators();
        this.createSwitches();
        this.createNumberFields();
        this.createNumberControls(); */
    this.cdRef.detectChanges();
  }

  createLightIndicators() {
    this.logger.debug('synoptic: createLightIndicators');

    this.lightIndicators.forEach(lightContainer => {
      lightContainer.view.clear();
      const factory: ComponentFactory<LightIndicatorComponent> = this.resolver.resolveComponentFactory(LightIndicatorComponent);

      const symbolRef = lightContainer.view.createComponent(factory);

      const symbolStaticData = this.dataSvc.getSymbolData(lightContainer.el.nativeElement.getAttribute('itemName'));
      this.logger.debug(symbolStaticData);
      // attribute itemName includes the name of the item to be represented by this symbol
      symbolRef.instance.updateStaticData(symbolStaticData);

      this.symbolRefs.push(symbolRef);
    });
  }
  createSwitches() {
    this.logger.trace('synoptic: createSwitches');
    this.switches.forEach(switchRef => {

      switchRef.clear();
      const factory: ComponentFactory<SwitchComponent> = this.resolver.resolveComponentFactory(SwitchComponent);

      const symbolRef = switchRef.createComponent(factory);

      const symbolStaticData = this.dataSvc.getSymbolData(switchRef.element.nativeElement.getAttribute('itemName'));
      this.logger.debug(symbolStaticData);
      // attribute itemName includes the name of the item to be represented by this symbol
      symbolRef.instance.updateStaticData(symbolStaticData);

      this.symbolRefs.push(symbolRef);
    });
  }
  createNumberFields() {
    this.logger.trace('synoptic: createNumberFields');
    this.numberFields.forEach(numberFieldRef => {

      numberFieldRef.clear();
      const factory: ComponentFactory<NumberFieldComponent> = this.resolver.resolveComponentFactory(NumberFieldComponent);

      const symbolRef = numberFieldRef.createComponent(factory);

      const symbolStaticData = this.dataSvc.getSymbolData(numberFieldRef.element.nativeElement.getAttribute('itemName'));
      this.logger.debug(symbolStaticData);
      // attribute itemName includes the name of the item to be represented by this symbol
      symbolRef.instance.updateStaticData(symbolStaticData);

      this.symbolRefs.push(symbolRef);
    });
  }
  createNumberControls() {
    this.logger.trace('synoptic: createNumberControls');
    this.numberControls.forEach(numberControlRef => {

      numberControlRef.clear();
      const factory: ComponentFactory<NumberControlComponent> = this.resolver.resolveComponentFactory(NumberControlComponent);

      const symbolRef = numberControlRef.createComponent(factory);

      const symbolStaticData = this.dataSvc.getSymbolData(numberControlRef.element.nativeElement.getAttribute('itemName'));
      this.logger.debug(symbolStaticData);
      // attribute itemName includes the name of the item to be represented by this symbol
      symbolRef.instance.updateStaticData(symbolStaticData);

      this.symbolRefs.push(symbolRef);
    });
  }
}
