import { Component, OnInit, TemplateRef, ViewChildren, QueryList } from '@angular/core';
import { FlatTreeControl } from '@angular/cdk/tree';
import { MatTreeFlatDataSource, MatTreeFlattener } from '@angular/material/tree';
import { NGXLogger } from 'ngx-logger';
import { DataService } from 'src/app/shared/services/data.config.service';
import { LoadSynoTemplateDirective } from 'src/app/views/abstract-synoptic/load-syno-template.directive';

/** Flat node with expandable and level information */
interface TreeNode {
  expandable: boolean;
  name: string;
  level: number;
}

@Component({
  selector: 'app-syno-manager',
  templateUrl: './syno-manager.component.html',
  styleUrls: ['./syno-manager.component.scss']
})
export class SynoManagerComponent implements OnInit {

  templateToShow: TemplateRef<HTMLElement> = null;
  currentSyno: string;
  //@ViewChildren(LoadSynoTemplateDirective) synoTemplateRefs: QueryList<LoadSynoTemplateDirective>;


  private _transformer = (node: any, level: number) => {
    this.logger.debug(node);
    return {
      expandable: !!node.children && node.children.length > 0,
      name: node.name,
      level: level,
    };
  }
  treeControl = new FlatTreeControl<TreeNode>(
    node => node.level, node => node.expandable);

  treeFlattener = new MatTreeFlattener(
    this._transformer, node => node.level, node => node.expandable, node => node.children);

  dataSource = new MatTreeFlatDataSource(this.treeControl, this.treeFlattener);

  constructor(private dataSvc: DataService, private logger: NGXLogger) {
    this.logger.debug(this.dataSource.data);
    this.dataSource.data = dataSvc.getSynoTree();

  }

  ngOnInit(): void {
  }
  hasChild = (_: number, node: TreeNode) => node.expandable;

  loadSynoptic(event: MouseEvent, node: TreeNode) {
    this.logger.debug("loadSynoptic: ", node);
    this.currentSyno = this.dataSvc.getSynoData(node.name).templateName;
  }
}
