import { NgModule } from '@angular/core';
import { CommonModule } from '@angular/common';
import { SharedModule } from 'src/app/shared/shared.module';
import { environment } from 'src/environments/environment';
import { StoreDevtoolsModule } from '@ngrx/store-devtools';
import { AbstractSynopticComponent } from 'src/app/views/abstract-synoptic/abstract-synoptic.component';
import { Syno1Component } from 'src/app/views/syno-views/syno1/syno1.component';
import { Syno2Component } from 'src/app/views/syno-views/syno2/syno2.component';
import { SynoManagerRoutingModule } from 'src/app/views/syno-manager/syno-manager-routing.module';
import { StoreModule } from '@ngrx/store';
import { EffectsModule } from '@ngrx/effects';
import * as fromAcqs from 'src/app/shared/state/acquisition';
import { AcquisitionsEffects } from 'src/app/shared/state/acquisition/acquisition.effects';
import { AcquisitionsStoreFacade } from 'src/app/shared/state/acquisition/acquisition.store-facade';
import { AcquisitionsService } from 'src/app/shared/services/acquisitions.service';
import * as fromCmds from 'src/app/shared/state/command';
import { CommandsEffects } from 'src/app/shared/state/command/command.effects';
import { CommandsStoreFacade } from 'src/app/shared/state/command/command.store-facade';
import { CommandsService } from 'src/app/shared/services/commands.service';
import { LightIndicatorComponent } from 'src/app/symbols/light-indicator/light-indicator.component';
import { SwitchComponent } from 'src/app/symbols/switch/switch.component';
import { NumberFieldComponent } from 'src/app/symbols/number-field/number-field.component';
import { NumberControlComponent } from 'src/app/symbols/number-control/number-control.component';
import { LoadSynoTemplateDirective } from 'src/app/views/abstract-synoptic/load-syno-template.directive';
import { SymbolContainer } from 'src/app/views/abstract-synoptic/symbol.container.directive';
import { SynoManagerComponent } from './syno-manager.component';


@NgModule({
  declarations: [
    LoadSynoTemplateDirective,
    SymbolContainer,
    LightIndicatorComponent,
    SwitchComponent,
    NumberFieldComponent,
    NumberControlComponent,
    AbstractSynopticComponent,
    Syno1Component,
    Syno2Component,
    SynoManagerComponent
  ],
  imports: [
    CommonModule,
    //SynoManagerRoutingModule,
    SharedModule,
    StoreModule.forFeature('acqs', fromAcqs.reducers),
    EffectsModule.forFeature([AcquisitionsEffects]),
    StoreModule.forFeature('cmds', fromCmds.reducers),
    EffectsModule.forFeature([CommandsEffects]),
    !environment.production ? StoreDevtoolsModule.instrument() : []
  ],
  providers: [AcquisitionsStoreFacade,
    AcquisitionsService, CommandsStoreFacade,
    CommandsService],
  entryComponents: [LightIndicatorComponent, SwitchComponent, NumberFieldComponent, NumberControlComponent],
  exports: [SynoManagerComponent]
})
export class SynoManagerModule { }
